package Data::Object::Func::String;

use Data::Object 'Class';

extends 'Data::Object::Func';

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Func::String

=cut

=head1 ABSTRACT

Functions for String Data

=cut

=head1 SYNOPSIS

  use Data::Object::Func::String;

=cut

=head1 DESCRIPTION

Data::Object::Func::String is an abstract base class for function classes in
the Data::Object::Func::String space.

=cut
